pub struct Control(/* private fields */);Expand description
APS frame control field.
Implementations
Sourceimpl Control
impl Control
Sourcepub const FRAME_TYPE: Self
pub const FRAME_TYPE: Self
Frame type mask.
Sourcepub const DELIVERY_MODE: Self
pub const DELIVERY_MODE: Self
Delivery mode mask.
Sourcepub const ACK_FORMAT: Self
pub const ACK_FORMAT: Self
Indicate if the frame is a command frame.
Sourcepub const ACK_REQUEST: Self
pub const ACK_REQUEST: Self
Acknowledgment request flag.
Sourcepub const EXTENDED_HEADER: Self
pub const EXTENDED_HEADER: Self
Extended header flag.
Sourceimpl Control
impl Control
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Control
impl Control
Sourcepub const fn iter(&self) -> Iter<Control>
pub const fn iter(&self) -> Iter<Control>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Control>
pub const fn iter_names(&self) -> IterNames<Control>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Control
impl Control
Sourcepub fn frame_type(self) -> FrameType
pub fn frame_type(self) -> FrameType
Return the frame type.
Sourcepub const fn set_frame_type(&mut self, frame_type: FrameType)
pub const fn set_frame_type(&mut self, frame_type: FrameType)
Set the frame type.
Sourcepub fn delivery_mode(self) -> Option<DeliveryMode>
pub fn delivery_mode(self) -> Option<DeliveryMode>
Return the delivery mode.
Sourcepub const fn set_delivery_mode(&mut self, delivery_mode: DeliveryMode)
pub const fn set_delivery_mode(&mut self, delivery_mode: DeliveryMode)
Set the delivery mode.
Sourcepub const fn set_destination(&mut self, destination: WeakDestination)
pub const fn set_destination(&mut self, destination: WeakDestination)
Set the delivery mode based on the destination type.
Sourcepub fn set_extended_header(&mut self, extended_header_present: bool)
pub fn set_extended_header(&mut self, extended_header_present: bool)
Set whether an extended header is present.